<?php

namespace Drupal\preprocessors\PluginManager\PreprocessorsPluginManager\Annotation;

use Drupal\Component\Annotation\Plugin;
use Drupal\preprocessors\PluginManager\PreprocessorsPluginManager\PreprocessorPluginBase as PluginBase;

/**
 * Defines a Preprocessor item annotation object.
 *
 * Plugin Namespace: Plugin\Preprocessor.
 *
 * @see plugin_api
 *
 * @package Drupal\preprocessors\Annotation
 *
 * @Annotation
 */
final class Preprocessor extends Plugin {

  /**
   * The plugin ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The target theme hook suggestion to preprocess variables for.
   *
   * @var string
   */
  protected $themeHook;

  /**
   * The themes to preprocess variables in.
   *
   * @var array
   */
  protected $themes;

  /**
   * The weight of this preprocessor.
   *
   * @var string
   */
  protected $weight = 0;

  /**
   * {@inheritdoc}
   */
  public function getThemeHook(): string {
    return $this->definition[PluginBase::THEME_HOOK];
  }

  /**
   * {@inheritdoc}
   */
  public function getThemes(): array {
    return $this->definition[PluginBase::THEMES];
  }

  /**
   * {@inheritdoc}
   */
  public function getWeight(): int {
    return $this->definition[PluginBase::WEIGHT] ?? 0;
  }

}
